<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Actions;

use Exception;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Debug;

class Addon
{
    /**
     * @return array
     */
    public function activate()
    {
        try {
            (new Install())->all();
            return [
                'status' => 'success',
            ];
        } catch (Exception $e) {
            Debug::sentry($e->getFile(), $e->getLine(), $e->getMessage(), 'Fatal');

            return [
                'status' => 'error',
                'description' => 'Failed: ' . $e->getMessage(),
            ];
        }
    }

    /**
     * @return array
     */
    public function deactivate()
    {
        try {
            (new Install())->drop();
            return [
                'status' => 'success',
            ];
        } catch (Exception $e) {
            Debug::sentry($e->getFile(), $e->getLine(), $e->getMessage(), 'Fatal');

            return [
                'status' => 'error',
                'description' => 'Failed: ' . $e->getMessage(),
            ];
        }
    }

    /**
     * @param array $vars
     *
     * @return void
     */
    public function upgrade(array $vars)
    {
        $currentVersion = $vars['version'];

        if (version_compare($currentVersion, '0.0.3', '<')) {
            try {
                (new Install())->upgrade003();
            } catch (Exception $e) {
                Debug::sentry($e->getFile(), $e->getLine(), $e->getMessage(), 'Fatal');
            }
        }
    }
}
