<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Controllers;

use Throwable;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\AdminManager;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\PushQueue;
use WHMCS\Scheduling\Jobs\Queue;

class AdminController extends Controller
{
    /**
     * @var AdminManager
     */
    private $manager;

    /**
     * @param AdminManager $manager
     */
    public function __construct(AdminManager $manager)
    {
        $this->manager = $manager;
    }

    /**
     * @return AdminManager
     */
    protected function manager()
    {
        return $this->manager;
    }

    /**
     * Index
     *
     * @param array $vars
     * @return void
     */
    public function index($vars)
    {
        if (!is_array($vars)) {
            $vars = [];
        }

        $vars['options'] = $this->manager()->options();
        $vars['suites'] = $this->manager()->suites();
        $vars['push_info_endpoint'] = $this->manager()->pushInfoEndpoint();
        $vars['push_send_endpoint'] = $this->manager()->pushSendEndpoint();
        $vars['push_queue_count'] = Queue::where('name', 'like', PushQueue::QUEUE_PREFIX_NAME . '%')->count();

        $this->render('admin/index.tpl', $vars);
    }

    /**
     * Push info
     *
     * @return void
     */
    public function pushInfo()
    {
        check_token('WHMCS.admin.default');
        $group_id = intval($_REQUEST['gid']);

        $info = null;
        $error = null;
        try {
            $info = $this->manager()->pushInfo($group_id);
            if (empty($info)) {
                $info = 'No active services were found for updates to this option group';
            }
        } catch (Throwable $e) {
            $error = $e->getMessage();
        }

        $this->jsonResponse([
            'info' => $info,
            'error' => $error,
        ]);
    }

    /**
     * Push send
     *
     * @return void
     */
    public function pushSend()
    {
        check_token('WHMCS.admin.default');
        $group_id = intval($_REQUEST['gid']);

        $this->manager()->pushSend($group_id);

        $this->redirectBack();
    }

    /**
     * Install
     *
     * @return void
     */
    public function install()
    {
        $this->manager()->install();

        $this->redirectBack();
    }

    /**
     * Configure Suite
     *
     * @return void
     */
    public function suiteConfigure()
    {
        check_token('WHMCS.admin.default');

        $id = (int)$_GET['id'];

        $this->manager()->suiteConfigure($id);

        $this->redirectBack();
    }

    /**
     * Delete Suite
     *
     * @return void
     */
    public function suiteDelete()
    {
        check_token('WHMCS.admin.default');

        $id = (int)$_GET['id'];

        $this->manager()->suiteDelete($id);

        $this->redirectBack();
    }
}
