<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Controllers;

use Smarty;
use Throwable;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Config;

abstract class Controller
{
    /**
     * Dispatch request.
     *
     * @param string $action
     * @param array $parameters
     *
     * @return void
     */
    public function dispatch(string $action, array $parameters)
    {
        $action = preg_replace('/[^a-z\d_]/i', '', $action);
        if (empty($action)) {
            $action = 'index';
        }

        if (is_callable([$this, $action])) {
            $this->$action($parameters);
            return;
        }

        echo '<p>Page not found.</p>';
    }

    /**
     * Render template
     *
     * @param string $template Path to file
     * @param array $vars Module configuration parameters
     * @return void
     */
    public function render(string $template, array $vars = [])
    {
        try {
            $smarty = new Smarty();

            foreach ($vars as $key => $val) {
                $smarty->assign($key, $val);
            }

            $smarty->setCaching(Smarty::CACHING_OFF);
            $smarty->setCompileDir($GLOBALS['templates_compiledir']);
            $smarty->display(Config::instance()->pathModule() . '/templates/' . $template);
        } catch (Throwable $e) {
            echo 'Error: ' . $e->getMessage();
        }
    }

    /**
     * @return void
     */
    protected function jsonResponse(array $data)
    {
        ob_clean();
        echo json_encode($data);
        die();
    }

    /**
     * @return void
     */
    protected function redirectBack()
    {
        $url = Config::instance()->baseUrlAdminAddon();
        header('Location: ' . $url, true, 302);
        exit();
    }

    /**
     * @param array $vars
     * @return mixed
     */
    abstract public function index($vars);
}
