<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;

abstract class OptionsModel extends Model
{
    /**
     * CL names
     *
     * @param Builder $query
     * @return Builder
     */
    public function scopeCloudLinuxNames(Builder $query)
    {
        $slugs = $this->cloudLinuxSlugs();

        $query->where(function (Builder $query) use ($slugs) {
            foreach ($slugs as $slug) {
                $query->orWhere(function (Builder $query) use ($slug) {
                    return $query->where('optionname', 'like', $slug . '|%');
                });
            }
        });

        return $query;
    }

    /**
     * @return string
     */
    public function cloudLinuxSlug()
    {
        $parts = explode('|', $this->optionname);
        return (string)$parts[0];
    }

    /**
     * @return array
     */
    abstract public function cloudLinuxSlugs();
}
