<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;

class Product extends \WHMCS\Product\Product
{
    /**
     * @return BelongsToMany
     */
    public function productConfigGroups()
    {
        return $this->belongsToMany(ProductConfigGroup::class, 'tblproductconfiglinks', 'pid', 'gid');
    }

    /**
     * @param Builder $query
     * @return Builder
     */
    public function scopeTypeHostingAccount(Builder $query)
    {
        return $query->where('type', self::TYPE_SHARED);
    }

    /**
     * Get hosting plans that have a group of options linked that contain MyImunify Account Protection
     * Including services (user orders) with previously purchased MyImunify Account Protection options
     * @param Builder $query
     * @param int $group_id
     * @return Builder
     */
    public function scopePushDataMyImunifyAccountProtection(Builder $query, $group_id)
    {
        return $query->typeHostingAccount()
            ->whereHas('productConfigGroups', function ($query) use ($group_id) {
                return $query->where('tblproductconfiggroups.id', $group_id)
                    ->whereHas('productConfigOptions', function ($query) {
                        return $query->myImunifyAccountProtection()->whereHas('productConfigOptionSubs');
                    });
            })->whereHas('services', function ($query) {
                return $query->active()->whereHas('serverModel');
            })->with([
                'services' => function ($query) {
                    return $query->active()->with([
                        'serverModel',
                        'configOptionsCloudLinux' => function ($query) {
                            return $query->with([
                                'productConfigOptionCloudLinux' => function ($query) {
                                    return $query->with('productConfigOptionGroup');
                                },
                                'productConfigOptionSubCloudLinux',
                            ]);
                        },
                    ]);
                },
                'productConfigGroups' => function ($query) use ($group_id) {
                    return $query->where('tblproductconfiggroups.id', $group_id)
                        ->whereHas('productConfigOptions', function ($query) {
                            return $query->myImunifyAccountProtection();
                        })
                        ->with([
                            'productConfigOptions' => function ($query) {
                                return $query->myImunifyAccountProtection()
                                    ->with([
                                        'productConfigOptionSubs'
                                    ]);
                            }
                        ]);
                }
            ]);
    }

    /**
     * @return HasMany
     */
    public function services()
    {
        return $this->hasMany(Service::class, "packageid");
    }
}
