<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Cdn;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Factory as SuitesFactory;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Premium;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Protection;

class ProductConfigOption extends OptionsModel
{
    /**
     * @var bool
     */
    public $timestamps = false;

    /**
     * @var string
     */
    protected $table = 'tblproductconfigoptions';

    /**
     * The attributes that are mass assignable.
     *
     * @var string[]
     */
    protected $fillable = [
        'gid',
        'optionname',
        'optiontype',
        'qtyminimum',
        'qtymaximum',
        'order',
        'hidden',
    ];

    /**
     * Premium
     *
     * @param Builder $query
     * @return Builder
     */
    public function scopeAwpPremium(Builder $query)
    {
        return $query->where('optionname', 'like', Premium::SLUG . '|%');
    }

    /**
     * CDN
     *
     * @param Builder $query
     * @return Builder
     */
    public function scopeAwpCdn(Builder $query)
    {
        return $query->where('optionname', 'like', Cdn::SLUG . '|%');
    }

    /**
     * MyImunify Account protection
     *
     * @param Builder $query
     * @return Builder
     */
    public function scopeMyImunifyAccountProtection(Builder $query)
    {
        return $query->where('optionname', 'like', Protection::SLUG . '|%');
    }

    /**
     * @return BelongsTo
     */
    public function productConfigOptionGroup()
    {
        return $this->belongsTo(ProductConfigGroup::class, 'gid');
    }

    /**
     * @return HasMany
     */
    public function productConfigOptionSubs()
    {
        return $this->hasMany(ProductConfigOptionSub::class, 'configid');
    }

    /**
     * @return bool
     */
    public function isHidden()
    {
        return (bool)$this->getAttribute('hidden') == true;
    }

    /**
     * @return array
     */
    public function cloudLinuxSlugs()
    {
        return array_keys(SuitesFactory::SUITES);
    }
}
