<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Factory as StatusesFactory;

class ProductConfigOptionSub extends OptionsModel
{
    /**
     * @var bool
     */
    public $timestamps = false;

    /**
     * @var string
     */
    protected $table = 'tblproductconfigoptionssub';

    /**
     * The attributes that are mass assignable.
     *
     * @var string[]
     */
    protected $fillable = [
        'configid',
        'optionname',
        'sortorder',
        'hidden',
    ];

    /**
     * CloudLinux
     *
     * @param Builder $query
     * @return Builder
     */
    public function scopeCloudLinux(Builder $query)
    {
        return $this->cloudLinuxNames();
    }

    /**
     * @return BelongsTo
     */
    public function productConfigOption()
    {
        return $this->belongsTo(ProductConfigOption::class, 'configid');
    }

    /**
     * @return HasMany
     */
    public function pricings()
    {
        // @phpstan-ignore-next-line
        return $this->hasMany(Pricing::class, 'relid')->where('type', 'configoptions');
    }

    /**
     * @return array
     */
    public function cloudLinuxSlugs()
    {
        return array_keys(StatusesFactory::STATUSES);
    }
}
