<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\AccelerateWp;

use Exception;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\Cpanel as Client;

class Cpanel extends Api
{
    /** @var Client */
    private $client;

    /** @var string */
    private $user;

    /** @var string */
    private $endpoint = '/cgi/CloudLinux.cgi';

    /**
     * @param Client $client
     * @param string $user
     */
    public function __construct(Client $client, string $user)
    {
        $this->client = $client;
        $this->user = $user;
    }

    /**
     * @return Client
     */
    public function client()
    {
        return $this->client;
    }

    /**
     * @return string
     */
    public function user()
    {
        return $this->user;
    }

    /**
     * @return string
     */
    private function endpoint()
    {
        return $this->endpoint;
    }

    /**
     * @param string $suite
     * @param string $status
     * @param array $attributes
     * @return array
     */
    private function data(string $suite, string $status, array $attributes)
    {
        return [
            'cgiaction' => 'jsonhandler',
            'handler' => 'set-suite',
            'command' => 'cloudlinux-awp-admin',
            'suites' => $suite,
            'users' => $this->user(),
            'source' => 'BILLING_OVERRIDE',
            'attrs' => json_encode($attributes),
            $status => '',
        ];
    }

    /**
     * @param string $suite
     * @param array $attributes
     * @return void
     * @throws Exception
     */
    public function default(string $suite, array $attributes)
    {
        $data = $this->data($suite, Status::DEFAULT, $attributes);
        $response = $this->client()->request($data, $this->endpoint());
        $this->responseValidation($response);
    }

    /**
     * @param string $suite
     * @param array $attributes
     * @return void
     * @throws Exception
     */
    public function allowed(string $suite, array $attributes)
    {
        $data = $this->data($suite, Status::ALLOWED, $attributes);
        $response = $this->client()->request($data, $this->endpoint());
        $this->responseValidation($response);
    }

    /**
     * @param string $suite
     * @param array $attributes
     * @return void
     * @throws Exception
     */
    public function disallowed(string $suite, array $attributes)
    {
        $data = $this->data($suite, Status::DISALLOWED, $attributes);
        $response = $this->client()->request($data, $this->endpoint());
        $this->responseValidation($response);
    }

    /**
     * @param array $response
     * @return void
     * @throws Exception
     */
    private function responseValidation(array $response)
    {
        if ($response['result'] !== 'success') {
            throw new Exception('Unexpected result: ' . var_export($response, true));
        }
    }
}
