<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\AccelerateWp;

use Exception;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\Plesk as Client;

class Plesk extends Api
{
    /** @var Client */
    private $client;

    /** @var string */
    private $user;

    /** @var string */
    private $domain;

    /**
     * @param Client $client
     * @param string $user
     * @param string $domain
     */
    public function __construct(Client $client, string $user, string $domain)
    {
        $this->client = $client;
        $this->user = $user;
        $this->domain = $domain;
    }

    /**
     * @return Client
     */
    public function client()
    {
        return $this->client;
    }

    /**
     * @return string
     */
    public function user()
    {
        return $this->user;
    }

    /**
     * @return string
     */
    public function domain()
    {
        return $this->domain;
    }

    /**
     * @param string $suite
     * @param string $status
     * @param array $attributes
     * @return string
     */
    private function data(string $suite, string $status, array $attributes)
    {
        return '<packet>
    <extension>
        <call>
            <accelerate-wp>
                <cloudlinux-awp-admin>
                    <command>set-suite</command>
                    <suites>' . $suite . '</suites>
                    <users>' . $this->user() . '</users>
                    <domains>' . $this->domain() . '</domains>
                    <source>BILLING_OVERRIDE</source>
                    <attrs>' . json_encode($attributes) . '</attrs>
                    <' . $status . '/>
                </cloudlinux-awp-admin>
            </accelerate-wp>
        </call>
    </extension>
</packet>';
    }

    /**
     * @param string $suite
     * @param array $attributes
     * @return void
     * @throws Exception
     */
    public function default(string $suite, array $attributes)
    {
        $data = $this->data($suite, Status::DEFAULT, $attributes);
        $this->client()->request($data);
    }

    /**
     * @param string $suite
     * @param array $attributes
     * @return void
     * @throws Exception
     */
    public function allowed(string $suite, array $attributes)
    {
        $data = $this->data($suite, Status::ALLOWED, $attributes);
        $this->client()->request($data);
    }

    /**
     * @param string $suite
     * @param array $attributes
     * @return void
     * @throws Exception
     */
    public function disallowed(string $suite, array $attributes)
    {
        $data = $this->data($suite, Status::DISALLOWED, $attributes);
        $this->client()->request($data);
    }
}
