<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api;

use Exception;

abstract class Client
{
    /**
     * @var array
     */
    private static $instances = [];

    /**
     * @var int
     */
    private $serverId = 0;

    protected function __construct()
    {
    }

    protected function __clone()
    {
    }

    /**
     * @throws Exception
     */
    public function __wakeup()
    {
        throw new Exception("Cannot unserialize a singleton.");
    }

    /**
     * @param int $serverId
     * @return Client
     */
    public static function getInstance(int $serverId)
    {
        $class = get_called_class();
        $key = $class . '.' . $serverId;

        if (!array_key_exists($key, self::$instances)) {
            $client = new static(); // @phpstan-ignore-line
            $client->setServerId($serverId);

            self::$instances[$key] = $client;
        }

        return self::$instances[$key];
    }

    /**
     * @param int $serverId
     * @return self
     */
    protected function setServerId(int $serverId)
    {
        $this->serverId = $serverId;

        return $this;
    }

    /**
     * @return int
     */
    protected function serverId()
    {
        return $this->serverId;
    }

    /**
     * @return int
     */
    protected function timeout()
    {
        $timeout = 25;

        if (defined('CLOUDLINUX_QUEUE') && CLOUDLINUX_QUEUE) {
            $timeout = 120;
        }

        return $timeout;
    }
}
