<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api;

use Exception;
use WHMCS\Module\Server;

class DirectAdmin extends Client
{
    /**
     * @var string
     */
    private $endpoint = '';

    /**
     * @var array
     */
    private $headers = [];

    /**
     * @return string
     */
    public function endpoint()
    {
        return $this->endpoint;
    }

    /**
     * @return array
     */
    public function headers()
    {
        return $this->headers;
    }

    /**
     * @return array
     */
    protected function serverParams()
    {
        return (new Server())->getServerParams($this->serverId());
    }

    /**
     * @return void
     * @throws Exception
     */
    public function setup()
    {
        $params = $this->serverParams();
        $this->setEndpoint($params);
        $this->setHeaders($params);
    }

    /**
     * @param array $params
     * @return void
     */
    public function setEndpoint(array $params)
    {
        $protocol = array_key_exists('serverhttpprefix', $params) ? $params['serverhttpprefix'] : '';
        $host = array_key_exists('serverhostname', $params) ? $params['serverhostname'] : '';
        $port = array_key_exists('serverport', $params)
            &&
            ! empty($params['serverport']) ? ':' . $params['serverport'] : ':2222';
        if (!empty($protocol) && !empty($host)) {
            $this->endpoint = $protocol
                . '://'
                . $host
                . $port
                . '/CMD_PLUGINS_ADMIN/lvemanager_spa/index.raw?c=send-request';
        }
    }

    /**
     * @param array $params
     * @return void
     */
    public function setHeaders(array $params)
    {
        $key = array_key_exists('serveraccesshash', $params) ? $params['serveraccesshash'] : '';
        $login = array_key_exists('serverusername', $params) ? $params['serverusername'] : '';
        $password = array_key_exists('serverpassword', $params) ? $params['serverpassword'] : '';

        if (!empty($key)) {
            $authstr = base64_encode($login . ":" . $key);
        } else {
            $authstr = base64_encode($login . ":" . $password);
        }
        $headers = [
            "Authorization: Basic " . $authstr,
        ];

        $this->headers = $headers;
    }

    /**
     * @param string $body
     * @return array
     * @throws Exception
     */
    public function request(string $body)
    {
        if (empty($this->endpoint())) {
            $this->setup();
        }

        $token = md5(uniqid((string) rand(), true));
        $body .= '&csrftoken=' . $token;

        $ch = curl_init();

        curl_setopt($ch, CURLOPT_URL, $this->endpoint());
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $body);
        curl_setopt($ch, CURLOPT_TIMEOUT, $this->timeout());
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_COOKIE, 'csrftoken=' . $token);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $this->headers());
        $response = curl_exec($ch);
        $error = '';
        if (curl_errno($ch)) {
            $error = curl_error($ch);
        }
        $code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        if ($code !== 200) {
            throw new Exception(trim('Wrong HTTP code: ' . $code . ' ' . $error . ' ' . $response));
        }

        if (empty($response) || !is_string($response)) {
            throw new Exception('Empty response');
        }

        if (strpos($response, 'UNAUTHORIZED') == true) {
            throw new Exception('Login Failed');
        }

        if (strpos($response, 'Your IP is blacklisted') !== false) {
            throw new Exception('WHMCS Host Server IP is Blacklisted');
        }

        $data = json_decode($response, true);
        if (!is_array($data)) {
            throw new Exception('Unexpected response: ' . $response);
        }

        if (array_key_exists('result', $data) && $data['result'] === 'success') {
            return $data;
        } else {
            throw new Exception('Unexpected response: ' . $response);
        }
    }
}
