<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\MyImunify;

use Exception;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\Cpanel as Client;

class Cpanel extends Api
{
    /** @var Client */
    private $client;

    /** @var string */
    private $user;

    /** @var string */
    private $endpoint = '/cgi/imunify/handlers/sendRequest.cgi';

    /**
     * @param Client $client
     * @param string $user
     */
    public function __construct(Client $client, string $user)
    {
        $this->client = $client;
        $this->user = $user;

        $this->client()->setHeader('Content-type', 'application/json; charset=utf-8');
    }

    /**
     * @return Client
     */
    public function client()
    {
        return $this->client;
    }

    /**
     * @return array
     */
    public function users()
    {
        return array_map('trim', explode(',', $this->user));
    }

    /**
     * @return string
     */
    private function endpoint()
    {
        return $this->endpoint;
    }

    /**
     * @param string $suite
     * @param string $status
     * @return array
     */
    private function data(string $suite, string $status)
    {
        return [
            'method' => ['myimunify', 'update'],
            'params' => [
                $suite  => $status,
                'items' => $this->users(),
            ],
        ];
    }

    /**
     * @param string $suite
     * @return void
     * @throws Exception
     */
    public function enable(string $suite)
    {
        $data = $this->data($suite, Status::ENABLE);
        $json = (string)json_encode($data);
        $response = $this->client()->request($json, $this->endpoint(), 'POST');
        $this->responseValidation($response);
    }

    /**
     * @param string $suite
     * @return void
     * @throws Exception
     */
    public function disable(string $suite)
    {
        $data = $this->data($suite, Status::DISABLE);
        $json = (string)json_encode($data);
        $response = $this->client()->request($json, $this->endpoint(), 'POST');
        $this->responseValidation($response);
    }

    /**
     * @param array $response
     * @return void
     * @throws Exception
     */
    private function responseValidation(array $response)
    {
        if (!in_array($response['result'], ['success', 'warnings'])) {
            throw new Exception('Unexpected result: ' . var_export($response, true));
        }
    }
}
