<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Services;

use WHMCS\Utility\Environment\WebHelper;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Models\Setting;

class Config
{
    public const VERSION = '0.0.4';

    /**
     * @var ?Config
     */
    private static $instance = null;

    /**
     * @var bool
     */
    private $debugStatus = false;

    /**
     * @var string
     */
    private $baseUrl;

    /**
     * @var string
     */
    private $baseUrlAdmin;

    /**
     * @var string
     */
    private $baseUrlAdminAddon;

    /**
     * @var string
     */
    private $pathModule;

    private function __construct()
    {
        if ($config = Setting::cloudlinuxAdvantage()->settingDebug()->first()) {
            $this->debugStatus = $config->value === 'on';
        }

        $this->baseUrl = rtrim(WebHelper::getBaseUrl(), '/');
        $this->baseUrlAdmin = rtrim(WebHelper::getAdminBaseUrl(), '/');
        $this->baseUrlAdminAddon = $this->baseUrlAdmin . '/addonmodules.php?module=cloudlinux_advantage';
        $this->pathModule = ROOTDIR . '/modules/addons/cloudlinux_advantage';
    }

    /**
     * @return Config
     */
    public static function instance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    /**
     * @return bool
     */
    public function debugStatus()
    {
        return $this->debugStatus;
    }

    /**
     * @return string
     */
    public function baseUrl()
    {
        return $this->baseUrl;
    }

    /**
     * @return string
     */
    public function baseUrlAdmin()
    {
        return $this->baseUrlAdmin;
    }

    /**
     * @return string
     */
    public function baseUrlAdminAddon()
    {
        return $this->baseUrlAdminAddon;
    }

    /**
     * @return string
     */
    public function pathModule()
    {
        return $this->pathModule;
    }
}
