<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Services;

class Debug
{
    /**
     * @param string $action
     * @param string|array $requestString
     * @param string|array $responseData
     * @param string|array $processedData
     * @param array $replaceVars
     * @return void
     */
    public static function log(
        string $action,
        $requestString,
        $responseData = '',
        $processedData = '',
        array $replaceVars = []
    ) {
        if (Config::instance()->debugStatus()) {
            logModuleCall(
                'cloudlinux_advantage',
                $action,
                $requestString,
                $responseData,
                $processedData,
                $replaceVars
            );
        }
    }

    /**
     * Get server ip.
     *
     * @return string|null
     */
    public static function serverIp()
    {
        $ip = null;
        if (
            isset($_SERVER['HTTP_CF_CONNECTING_IP']) &&
            filter_var($_SERVER['HTTP_CF_CONNECTING_IP'], FILTER_VALIDATE_IP)
        ) {
            $ip = $_SERVER['HTTP_CF_CONNECTING_IP'];
        } elseif (
            isset($_SERVER['SERVER_ADDR']) &&
            filter_var($_SERVER['SERVER_ADDR'], FILTER_VALIDATE_IP)
        ) {
            $ip = $_SERVER['SERVER_ADDR'];
        } elseif (function_exists('gethostbyname') && function_exists('gethostname')) {
            $hostname = gethostname();
            if (is_string($hostname)) {
                $ip = gethostbyname($hostname);
                if (!filter_var($ip, FILTER_VALIDATE_IP)) {
                    $ip = null;
                }
            }
        }

        return $ip;
    }

    /**
     * @param string $errfile
     * @param int $errline
     * @param string $errstr
     * @param string $errtype
     * @param array $extra
     * @return void
     */
    public static function sentry(string $errfile, int $errline, string $errstr, string $errtype, array $extra = [])
    {
        if (!function_exists('curl_init') || defined('IS_TESTING')) {
            return;
        }

        $server_ip = self::serverIp();

        $data = [
            'tags' => [
                'php_version' => phpversion(),
                'addon_version' => Config::VERSION,
            ],
            'user' => [
                'ip_address' => $server_ip,
            ],
            'extra' => $extra,
            'release' => 'whmcs-awp-plugin@' . Config::VERSION,
            'sentry.interfaces.Exception' => [
                'exc_omitted' => null,
                'values' => [
                    [
                        'stacktrace' => [
                            'frames' => [
                                [
                                    'filename' => $errfile,
                                    'lineno' => $errline,
                                ],
                            ],
                            'frames_omitted' => null,
                        ],
                        'type' => $errtype,
                        'value' => $errstr,
                    ],
                ],
            ],
        ];

        $sentry_key = 'b0770dd466ff4b039031da142feb96bc';
        $url = 'https://' . $sentry_key . '@cl.sentry.cloudlinux.com/api/26/store/';
        $auth = [
            'Sentry sentry_version=7',
            'sentry_timestamp=' . time(),
            'sentry_client=php-curl/1.0',
            'sentry_key=' . $sentry_key
        ];
        $headers = [
            'Content-Type: application/json',
            'X-Sentry-Auth: ' . implode(',', $auth),
        ];

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
        curl_setopt($ch, CURLOPT_TIMEOUT, 1);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 1);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_exec($ch);
        curl_close($ch);
    }
}
