<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites;

use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\AccelerateWp\Cpanel;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\AccelerateWp\Plesk;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\AccelerateWp\DirectAdmin;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\AccelerateWp\Status;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Off;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Cdn50Gb;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Cdn100Gb;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Cdn250Gb;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Cdn500Gb;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Cdn1Tb;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Cdn2d5Tb;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Cdn5Tb;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Cdn10Tb;

class Cdn extends Suite
{
    public const SLUG = 'accelerate_wp_cdn';
    public const NAME = self::SLUG . '|AccelerateWP CDN';
    public const PRINT = 'AccelerateWP CDN';
    public const OPTION_TYPE = 1; // Dropdown

    /**
     * @return string[]
     */
    public function aliases()
    {
        return [
            self::SLUG,
            'accelerate_wp_cdn_pro',
        ];
    }

    /**
     * @return string[]
     */
    public function statuses()
    {
        return [
            Off::SLUG => Off::class,
            Cdn50Gb::SLUG => Cdn50Gb::class,
            Cdn100Gb::SLUG => Cdn100Gb::class,
            Cdn250Gb::SLUG => Cdn250Gb::class,
            Cdn500Gb::SLUG => Cdn500Gb::class,
            Cdn1Tb::SLUG => Cdn1Tb::class,
            Cdn2d5Tb::SLUG => Cdn2d5Tb::class,
            Cdn5Tb::SLUG => Cdn5Tb::class,
            Cdn10Tb::SLUG => Cdn10Tb::class,
        ];
    }

    /**
     * @param string $serverType
     * @return ?string
     */
    public function apiClass(string $serverType)
    {
        $api = null;
        if ($serverType === 'cpanel') {
            $api = Cpanel::class;
        } elseif ($serverType === 'plesk') {
            $api = Plesk::class;
        } elseif ($serverType === 'directadmin') {
            $api = DirectAdmin::class;
        }

        return $api;
    }

    /**
     * @param string $status
     * @return string
     */
    public function apiSlug(string $status)
    {
        return 'accelerate_wp_cdn_pro';
    }

    /**
     * @param string $status
     * @return string
     */
    public function apiStatus(string $status)
    {
        if ($status === Off::SLUG) {
            return Status::DEFAULT;
        } else {
            return Status::ALLOWED;
        }
    }

    /**
     * @param array $options
     * @return string
     */
    public function preselectStatusWhenUpgradeSlug(array $options)
    {
        if (array_key_exists(Off::SLUG, $options) && $options[Off::SLUG]['selected'] === true) {
            return Cdn50Gb::SLUG;
        }

        return '';
    }

    /**
     * @return string
     */
    public function initialStatusSlug()
    {
        return Off::SLUG;
    }
}
