<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites;

use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\AccelerateWp\Cpanel;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\AccelerateWp\Plesk;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\AccelerateWp\DirectAdmin;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\AccelerateWp\Status;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Off;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\On;

class Premium extends Suite
{
    public const SLUG = 'accelerate_wp_premium';
    public const NAME = self::SLUG . '|AccelerateWP Premium';
    public const PRINT = 'AccelerateWP Premium';
    public const OPTION_TYPE = 2; // Radio

    /**
     * @return string[]
     */
    public function aliases()
    {
        return [
            self::SLUG,
        ];
    }

    /**
     * @return string[]
     */
    public function statuses()
    {
        return [
            Off::SLUG => Off::class,
            On::SLUG => On::class,
        ];
    }

    /**
     * @param string $serverType
     * @return ?string
     */
    public function apiClass(string $serverType)
    {
        $api = null;
        if ($serverType === 'cpanel') {
            $api = Cpanel::class;
        } elseif ($serverType === 'plesk') {
            $api = Plesk::class;
        } elseif ($serverType === 'directadmin') {
            $api = DirectAdmin::class;
        }

        return $api;
    }

    /**
     * @param string $status
     * @return ?string
     */
    public function apiSlug(string $status)
    {
        $map = [
            Off::SLUG => 'accelerate_wp_premium',
            On::SLUG => 'accelerate_wp_premium',
        ];

        if (array_key_exists($status, $map)) {
            return $map[$status];
        }

        return null;
    }

    /**
     * @param string $status
     * @return ?string
     */
    public function apiStatus(string $status)
    {
        $map = [
            Off::SLUG => Status::DEFAULT,
            On::SLUG => Status::ALLOWED,
        ];

        if (array_key_exists($status, $map)) {
            return $map[$status];
        }

        return null;
    }

    /**
     * @param array $options
     * @return string
     */
    public function preselectStatusWhenUpgradeSlug(array $options)
    {
        if (array_key_exists(Off::SLUG, $options) && $options[Off::SLUG]['selected'] === true) {
            return On::SLUG;
        }

        return '';
    }

    /**
     * @return string
     */
    public function initialStatusSlug()
    {
        return Off::SLUG;
    }
}
