<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites;

use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\MyImunify\Cpanel;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Api\MyImunify\Status;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\Off;
use WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites\Statuses\On;

class Protection extends Suite
{
    public const SLUG = 'my_imunify_account_protection';
    public const NAME = self::SLUG . '|MyImunify - Account protection';
    public const PRINT = 'MyImunify - Account protection';
    public const OPTION_TYPE = 2; // Radio

    /**
     * @return bool
     */
    public function pushable()
    {
        return true;
    }

    /**
     * @return string[]
     */
    public function aliases()
    {
        return [
            self::SLUG,
        ];
    }

    /**
     * @return string[]
     */
    public function statuses()
    {
        return [
            Off::SLUG => Off::class,
            On::SLUG => On::class,
        ];
    }

    /**
     * @param string $serverType
     * @return ?string
     */
    public function apiClass(string $serverType)
    {
        $api = null;
        if ($serverType === 'cpanel') {
            $api = Cpanel::class;
        }

        return $api;
    }

    /**
     * @param string $status
     * @return ?string
     */
    public function apiSlug(string $status)
    {
        $map = [
            Off::SLUG => 'protection',
            On::SLUG => 'protection',
        ];

        if (array_key_exists($status, $map)) {
            return $map[$status];
        }

        return null;
    }

    /**
     * @param string $status
     * @return ?string
     */
    public function apiStatus(string $status)
    {
        $map = [
            Off::SLUG => Status::DISABLE,
            On::SLUG => Status::ENABLE,
        ];

        if (array_key_exists($status, $map)) {
            return $map[$status];
        }

        return null;
    }

    /**
     * @param array $options
     * @return string
     */
    public function preselectStatusWhenUpgradeSlug(array $options)
    {
        if (array_key_exists(Off::SLUG, $options) && $options[Off::SLUG]['selected'] === true) {
            return On::SLUG;
        }

        return '';
    }

    /**
     * @return string
     */
    public function initialStatusSlug()
    {
        return Off::SLUG;
    }
}
