<?php

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WHMCS\Module\Addon\CloudlinuxAdvantage\Services\Suites;

abstract class Suite
{
    public const SLUG = '';
    public const NAME = '';
    public const PRINT = '';
    public const OPTION_TYPE = 2; // Radio

    /**
     * @return string
     */
    public function slug()
    {
        return static::SLUG;
    }

    /**
     * @return string
     */
    public function name()
    {
        return static::NAME;
    }

    /**
     * @return string
     */
    public function print()
    {
        return static::PRINT;
    }

    /**
     * @return int
     */
    public function optionType()
    {
        return static::OPTION_TYPE;
    }

    /**
     * @return bool
     */
    public function pushable()
    {
        return false;
    }

    /**
     * @param string $status
     * @return ?array
     */
    public function apiAttributes(string $status)
    {
        $map = $this->statuses();

        if (array_key_exists($status, $map)) {
            return $map[$status]::ATTRIBUTES;
        }

        return null;
    }

    /**
     * @return string[]
     */
    abstract public function aliases();

    /**
     * @return string[]
     */
    abstract public function statuses();

    /**
     * @param string $serverType
     * @return ?string
     */
    abstract public function apiClass(string $serverType);

    /**
     * @param string $status
     * @return ?string
     */
    abstract public function apiSlug(string $status);

    /**
     * @param string $status
     * @return ?string
     */
    abstract public function apiStatus(string $status);

    /**
     * @param array $options
     * @return string
     */
    abstract public function preselectStatusWhenUpgradeSlug(array $options);

    /**
     * @return string
     */
    abstract public function initialStatusSlug();
}
