<div class="alert alert-warning" role="alert">
    <h4>Configurable option status</h4>
    {foreach $options as $option}
        <div>
            {if $option.id eq 0}
                <span class="label label-danger">Missed</span>
                <a href="{$option.url}" class="label label-primary">Install</a>
            {else}
                {if $option.pushable}
                    <a href="javascript:void(0)" onclick="cloudlinuxAdvantagePush(this, '{$option.gid}')" class="label label-warning">Push</a>
                {/if}
            {/if}
            <a href="{$option.url}">{$option.name}</a><br>
        </div>
    {/foreach}
</div>

{if $push_queue_count gt 0}
    <div class="alert alert-warning" role="alert">
        Number of tasks ({$push_queue_count}) for pushing statuses to servers.
    </div>
{/if}

<hr>
<h3>CloudLinuxAdvantage last activation state</h3>
<p>Updating the data to the actual state of the client's service will be performed automatically by the cron or can be forced by the "Retry now" button.</p>
<table class="datatable" width="100%" border="0" cellspacing="1" cellpadding="3">
    <thead>
    <tr>
        <th>Service</th>
        <th>Server</th>
        <th>Suite</th>
        <th>Message</th>
        <th>Queue</th>
        <th>Action</th>
    </tr>
    </thead>
    <tbody>
    {if count($suites) gt 0}
        {foreach $suites as $suite}
            <tr>
                <td>
                    <i style="color: #cccccc;" class="fa fa-info-circle" data-toggle="tooltip" data-original-title="Client's service status"></i>
                    <a href="/admin/clientsservices.php?id={$suite.service_id}" target="_blank">
                        {$suite.service_title}
                    </a>
                    <br>
                    <small>
                        Last status: <span class="label label-info">{$suite.service_status}</span><br>
                        Current status: <span class="label label-info">{$suite.current_service_status}</span><br>
                        <br>
                    </small>
                </td>
                <td>
                    <a href="/admin/configservers.php?action=manage&id={$suite.server_id}" target="_blank">
                        {$suite.server_title}
                    </a>
                </td>
                <td>
                    <i style="color: #cccccc;" class="fa fa-info-circle" data-toggle="tooltip" data-original-title="Status of the selected configurable option for the client's service"></i> <strong>{$suite.suite_slug_print}</strong>
                    <br>
                    <small>
                        Last status: <span class="label label-info">{$suite.suite_status_print}</span><br>
                        Current status: <span class="label label-info">{$suite.current_suite_status_print}</span><br>
                        <i style="color: #cccccc;" class="fa fa-info-circle" data-toggle="tooltip" data-original-title="The status of suite depends on the status of the client's service and the selected configurable option"></i> Will set status: <span class="label label-info">{$suite.actual_suite_status_print}</span>
                    </small>
                </td>
                <td style="max-width: 400px;">
                    {$suite.report}<br>
                </td>
                <td>
                    {if empty($suite.queue_available_at)}
                        No
                    {else}
                        Automatic update will be started soon
                        <br>
                        <small>
                            Available at: {$suite.queue_available_at}<br>
                            {if !empty($suite.queue_started_at)}
                                Started at: {$suite.queue_started_at}
                            {/if}
                        </small>
                    {/if}
                </td>
                <td style="width: 85px;" class="text-center">
                    <a href="{$suite.retry_url}" class="btn btn-sm btn-primary btn-block">Retry now</a>
                    <a href="{$suite.delete_url}" class="btn btn-sm btn-link text-danger btn-block" onclick="return confirm('Delete?')">Delete</a>
                </td>
            </tr>
        {/foreach}
    {else}
        <td colspan="6" class="text-center">No Records Found</td>
    {/if}
    </tbody>
</table>

<div class="modal fade" id="cl-push-modal" tabindex="-1" role="dialog">
    <div class="modal-dialog modal-lg" role="document">
        <form action="{$push_send_endpoint}" method="POST" class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                <h4 class="modal-title">Push info</h4>
            </div>
            <div class="modal-body">
                ...
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-default" data-dismiss="modal">Cancel</button>
                <button type="submit" class="btn btn-primary">Send changes</button>
            </div>
            <input type="hidden" name="gid" value="0">
        </form>
    </div>
</div>

<script>
    var cloudlinuxAdvantagePushLoading = false
    window.cloudlinuxAdvantagePush = function (e, gid) {
        if (cloudlinuxAdvantagePushLoading === true) {
            return;
        }
        cloudlinuxAdvantagePushLoading = true;
        var name = e.innerHTML
        e.innerHTML = 'Loading...'
        var endpoint = '{$push_info_endpoint}&gid=' + gid
        WHMCS.http.jqClient.jsonGet({
            url: endpoint,
            success: function (response) {
                e.innerHTML = name
                cloudlinuxAdvantagePushLoading = false
                if (response.error !== null) {
                    alert(response.error)
                } else {
                    var modal = $('#cl-push-modal');
                    modal.modal('show')
                    modal.find('.modal-body').html(response.info)
                    modal.find('input[name="gid"]').val(gid)
                }
            },
            error: function () {
                e.innerHTML = name
                cloudlinuxAdvantagePushLoading = false
                alert('Request error...');
            }
        })
    }
</script>